==> pyconnectwise-0.5.0.tar.gz: pyconnectwise-0.5.0/src/pyconnectwise/endpoints/manage/FinanceBillingtermsIdEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.FinanceBillingtermsIdInfoEndpoint import FinanceBillingtermsIdInfoEndpoint
from pyconnectwise.endpoints.manage.FinanceBillingtermsIdUsagesEndpoint import FinanceBillingtermsIdUsagesEndpoint
from pyconnectwise.interfaces import IDeleteable, IGettable, IPaginateable, IPatchable, IPostable, IPuttable
from pyconnectwise.models.manage import BillingTerm
from pyconnectwise.responses.paginated_response import PaginatedResponse
from pyconnectwise.types import JSON, ConnectWiseAutomateRequestParams, ConnectWiseManageRequestParams, PatchRequestData


class FinanceBillingtermsIdEndpoint(
    ConnectWiseEndpoint,
    IGettable[BillingTerm, ConnectWiseManageRequestParams],
    IPuttable[BillingTerm, ConnectWiseManageRequestParams],
    IPatchable[BillingTerm, ConnectWiseManageRequestParams],
    IPaginateable[BillingTerm, ConnectWiseManageRequestParams],
):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "{id}", parent_endpoint=parent_endpoint)

        self.info = self._register_child_endpoint(FinanceBillingtermsIdInfoEndpoint(client, parent_endpoint=self))
        self.usages = self._register_child_endpoint(FinanceBillingtermsIdUsagesEndpoint(client, parent_endpoint=self))

    def paginated(
        self, page: int, page_size: int, params: ConnectWiseManageRequestParams | None = None
    ) -> PaginatedResponse[BillingTerm]:
        """
        Performs a GET request against the /finance/billingTerms/{id} endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[BillingTerm]: The initialized PaginatedResponse object.
        """
        if params:
            params["page"] = page
            params["pageSize"] = page_size
        else:
            params = {"page": page, "pageSize": page_size}
        return PaginatedResponse(
            super()._make_request("GET", params=params), BillingTerm, self, page, page_size, params
        )

    def get(self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None) -> BillingTerm:
        """
        Performs a GET request against the /finance/billingTerms/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            BillingTerm: The parsed response data.
        """
        return self._parse_one(BillingTerm, super()._make_request("GET", data=data, params=params).json())

    def delete(self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None) -> None:
        """
        Performs a DELETE request against the /finance/billingTerms/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        """
        super()._make_request("DELETE", data=data, params=params)

    def put(self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None) -> BillingTerm:
        """
        Performs a PUT request against the /finance/billingTerms/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            BillingTerm: The parsed response data.
        """
        return self._parse_one(BillingTerm, super()._make_request("PUT", data=data, params=params).json())

    def patch(self, data: PatchRequestData, params: ConnectWiseManageRequestParams | None = None) -> BillingTerm:
        """
        Performs a PATCH request against the /finance/billingTerms/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            BillingTerm: The parsed response data.
        """
        return self._parse_one(BillingTerm, super()._make_request("PATCH", data=data, params=params).json())

==> pyconnectwise-0.5.1.tar.gz: pyconnectwise-0.5.1/src/pyconnectwise/endpoints/manage/FinanceBillingtermsIdEndpoint.py <==
from typing import Any

from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.endpoints.manage.FinanceBillingtermsIdInfoEndpoint import FinanceBillingtermsIdInfoEndpoint
from pyconnectwise.endpoints.manage.FinanceBillingtermsIdUsagesEndpoint import FinanceBillingtermsIdUsagesEndpoint
from pyconnectwise.interfaces import IDeleteable, IGettable, IPaginateable, IPatchable, IPostable, IPuttable
from pyconnectwise.models.manage import BillingTerm
from pyconnectwise.responses.paginated_response import PaginatedResponse
from pyconnectwise.types import JSON, ConnectWiseAutomateRequestParams, ConnectWiseManageRequestParams, PatchRequestData


class FinanceBillingtermsIdEndpoint(
    ConnectWiseEndpoint,
    IGettable[BillingTerm, ConnectWiseManageRequestParams],
    IPuttable[BillingTerm, ConnectWiseManageRequestParams],
    IPatchable[BillingTerm, ConnectWiseManageRequestParams],
    IPaginateable[BillingTerm, ConnectWiseManageRequestParams],
):
    def __init__(self, client, parent_endpoint=None):
        ConnectWiseEndpoint.__init__(self, client, "{id}", parent_endpoint=parent_endpoint)
        IGettable.__init__(self, BillingTerm)
        IPuttable.__init__(self, BillingTerm)
        IPatchable.__init__(self, BillingTerm)
        IPaginateable.__init__(self, BillingTerm)

        self.usages = self._register_child_endpoint(FinanceBillingtermsIdUsagesEndpoint(client, parent_endpoint=self))
        self.info = self._register_child_endpoint(FinanceBillingtermsIdInfoEndpoint(client, parent_endpoint=self))

    def paginated(
        self, page: int, page_size: int, params: ConnectWiseManageRequestParams | None = None
    ) -> PaginatedResponse[BillingTerm]:
        """
        Performs a GET request against the /finance/billingTerms/{id} endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[BillingTerm]: The initialized PaginatedResponse object.
        """
        if params:
            params["page"] = page
            params["pageSize"] = page_size
        else:
            params = {"page": page, "pageSize": page_size}
        return PaginatedResponse(
            super()._make_request("GET", params=params), BillingTerm, self, page, page_size, params
        )

    def get(self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None) -> BillingTerm:
        """
        Performs a GET request against the /finance/billingTerms/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            BillingTerm: The parsed response data.
        """
        return self._parse_one(BillingTerm, super()._make_request("GET", data=data, params=params).json())

    def delete(self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None) -> None:
        """
        Performs a DELETE request against the /finance/billingTerms/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        """
        super()._make_request("DELETE", data=data, params=params)

    def put(self, data: JSON | None = None, params: ConnectWiseManageRequestParams | None = None) -> BillingTerm:
        """
        Performs a PUT request against the /finance/billingTerms/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            BillingTerm: The parsed response data.
        """
        return self._parse_one(BillingTerm, super()._make_request("PUT", data=data, params=params).json())

    def patch(self, data: PatchRequestData, params: ConnectWiseManageRequestParams | None = None) -> BillingTerm:
        """
        Performs a PATCH request against the /finance/billingTerms/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            BillingTerm: The parsed response data.
        """
        return self._parse_one(BillingTerm, super()._make_request("PATCH", data=data, params=params).json())
